@@ -1,12 +1,12 @@
-//@line 37 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 37 "browser/app/profile/firefox.js"
 
 // XXX Toolkit-specific preferences should be moved into toolkit.js
 
-//@line 41 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 41 "browser/app/profile/firefox.js"
 
-//@line 44 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 44 "browser/app/profile/firefox.js"
 
-//@line 50 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 50 "browser/app/profile/firefox.js"
 
 pref("general.startup.browser", true);
 
@@ -137,12 +137,12 @@ pref("keyword.URL", "chrome://browser-region/locale/region.properties");
 
 pref("general.useragent.locale", "en-US");
 pref("general.skins.selectedSkin", "classic/1.0");
-pref("general.useragent.extra.firefox", "IceCat/3.5");
+pref("general.useragent.extra.firefox", "IceCat/3.5.1");
 
 pref("general.smoothScroll", false);
-//@line 184 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 184 "browser/app/profile/firefox.js"
 pref("general.autoScroll", false);
-//@line 188 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 188 "browser/app/profile/firefox.js"
 
 // Whether or not the application should check at startup each time if it 
 // is the default browser.
@@ -162,11 +162,11 @@ pref("browser.warnOnRestart", true);
 pref("browser.fullscreen.autohide", true);
 pref("browser.fullscreen.animateUp", 1);
 
-//@line 208 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 208 "browser/app/profile/firefox.js"
 pref("browser.urlbar.clickSelectsAll", false);
-//@line 213 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 213 "browser/app/profile/firefox.js"
 pref("browser.urlbar.doubleClickSelectsAll", true);
-//@line 217 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 217 "browser/app/profile/firefox.js"
 pref("browser.urlbar.autoFill", false);
 // 0: Match anywhere (e.g., middle of words)
 // 1: Match on word boundaries and then try matching anywhere
@@ -318,9 +318,9 @@ pref("browser.bookmarks.max_backups",             5);
 
 // Scripts & Windows prefs
 pref("dom.disable_open_during_load",              true);
-//@line 372 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 372 "browser/app/profile/firefox.js"
 pref("javascript.options.showInConsole",          false);
-//@line 374 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 374 "browser/app/profile/firefox.js"
 
 // Make the status bar reliably present and unaffected by pages
 pref("dom.disable_window_open_feature.status",    true);
@@ -399,10 +399,10 @@ pref("browser.gesture.swipe.left", "Browser:BackOrBackDuplicate");
 pref("browser.gesture.swipe.right", "Browser:ForwardOrForwardDuplicate");
 pref("browser.gesture.swipe.up", "cmd_scrollTop");
 pref("browser.gesture.swipe.down", "cmd_scrollBottom");
-//@line 456 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 456 "browser/app/profile/firefox.js"
 pref("browser.gesture.pinch.latched", false);
 pref("browser.gesture.pinch.threshold", 25);
-//@line 459 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 459 "browser/app/profile/firefox.js"
 pref("browser.gesture.pinch.out", "cmd_fullZoomEnlarge");
 pref("browser.gesture.pinch.in", "cmd_fullZoomReduce");
 pref("browser.gesture.pinch.out.shift", "cmd_fullZoomReset");
@@ -414,7 +414,7 @@ pref("browser.gesture.twist.left", "");
 pref("browser.gesture.tap", "cmd_fullZoomReset");
 
 // 0=lines, 1=pages, 2=history , 3=text size
-//@line 484 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 484 "browser/app/profile/firefox.js"
 pref("mousewheel.withshiftkey.action",2);
 pref("mousewheel.withshiftkey.sysnumlines",false);
 pref("mousewheel.withshiftkey.numlines",1);
@@ -424,7 +424,7 @@ pref("mousewheel.withaltkey.numlines",1);
 pref("mousewheel.withmetakey.action",0);
 pref("mousewheel.withmetakey.sysnumlines",true);
 pref("mousewheel.withmetakey.numlines",1);
-//@line 494 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 494 "browser/app/profile/firefox.js"
 pref("mousewheel.withcontrolkey.action",3);
 pref("mousewheel.withcontrolkey.sysnumlines",false);
 pref("mousewheel.withcontrolkey.numlines",1);
@@ -484,11 +484,11 @@ pref("pfs.datasource.url", "https://pfs.mozilla.org/plugins/PluginFinderService.
 // by default we show an infobar message when pages require plugins the user has not installed
 pref("plugins.hide_infobar_for_missing_plugin", false);
 
-//@line 556 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 556 "browser/app/profile/firefox.js"
 pref("browser.preferences.instantApply", true);
-//@line 561 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 561 "browser/app/profile/firefox.js"
 pref("browser.preferences.animateFadeIn", false);
-//@line 563 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 563 "browser/app/profile/firefox.js"
 
 pref("browser.download.show_plugins_in_list", true);
 pref("browser.download.hide_plugins_without_extensions", true);
@@ -497,9 +497,9 @@ pref("browser.download.hide_plugins_without_extensions", true);
 // 0 goes Back/Forward
 // 1 act like PgUp/PgDown
 // 2 and other values, nothing
-//@line 572 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 572 "browser/app/profile/firefox.js"
 pref("browser.backspace_action", 2);
-//@line 576 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 576 "browser/app/profile/firefox.js"
 
 // this will automatically enable inline spellchecking (if it is available) for
 // editable elements in HTML
@@ -588,7 +588,7 @@ pref("gecko.handlerService.schemes.ircs.3.uriTemplate", "chrome://browser-region
 // By default, we don't want protocol/content handlers to be registered from a different host, see bug 402287
 pref("gecko.handlerService.allowRegisterFromDifferentHost", false);
 
-//@line 665 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 665 "browser/app/profile/firefox.js"
 // Safe browsing does nothing unless this pref is set
 pref("browser.safebrowsing.enabled", true);
 
@@ -633,23 +633,23 @@ pref("urlclassifier.gethashtables", "goog-phish-shavar,goog-malware-shavar");
 // the database.
 pref("urlclassifier.confirm-age", 2700);
 
-//@line 715 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 715 "browser/app/profile/firefox.js"
 
 // Maximum size of the sqlite3 cache during an update, in bytes
-//@line 718 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 718 "browser/app/profile/firefox.js"
 pref("urlclassifier.updatecachemax", 104857600);
-//@line 722 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 722 "browser/app/profile/firefox.js"
 
 // URL for checking the reason for a malware warning.
 pref("browser.safebrowsing.malware.reportURL", "http://safebrowsing.clients.google.com/safebrowsing/diagnostic?client=%NAME%&hl=%LOCALE%&site=");
 
-//@line 727 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 727 "browser/app/profile/firefox.js"
 
 pref("browser.EULA.version", 3);
 pref("browser.rights.version", 3);
 pref("browser.rights.3.shown", false);
 
-//@line 736 "/home/gscrivano/icecat/35/browser/app/profile/firefox.js"
+//@line 736 "browser/app/profile/firefox.js"
 
 pref("browser.sessionstore.resume_from_crash", true);
 pref("browser.sessionstore.resume_session_once", false);
